@@ -4,7 +4,7 @@
 #' This output format is built with [Bootstrap](https://getbootstrap.com),
 #' using carefully crafted features to provide a clean reading experience whether
 #' you are on a phone, tablet, or desktop. To read more about this format, see:
-#' \url{https://bookdown.org/yihui/bookdown/html.html#bootstrap4-style}
+#' \url{https://bookdown.org/yihui/bookdown/html.html#bs4-book}
 #'
 #' @param theme A named list or [bslib::bs_theme()] object.
 #'   The default, `bs4_book_theme()`, resets the base font size to 1rem to
@@ -22,6 +22,10 @@
 #'   start from the default template:
 #'   <https://github.com/rstudio/bookdown/blob/master/inst/templates/bs4_book.html>.
 #'   Otherwise, some feature may not work anymore.
+#' @param footnotes_inline By default, footnotes will be set inline and shown on
+#'   hover. Set to `FALSE` to keep footnotes at the bottom of the page with
+#'   links.
+#'
 #' @export
 #' @md
 bs4_book <- function(theme = bs4_book_theme(),
@@ -31,7 +35,8 @@ bs4_book <- function(theme = bs4_book_theme(),
                      pandoc_args = NULL,
                      extra_dependencies = NULL,
                      template = 'default',
-                     split_bib = FALSE) {
+                     split_bib = FALSE,
+                     footnotes_inline = TRUE) {
   check_packages(bs4_book_deps())
   bs4_check_dots(...)
 
@@ -65,7 +70,7 @@ bs4_book <- function(theme = bs4_book_theme(),
     }
 
     output2 <- bs4_book_build(output, repo = repo, lib_dir = lib_dir,
-                              split_bib = split_bib)
+                              split_bib = split_bib, footnotes_inline = footnotes_inline)
 
     if (clean && file.exists(output) && !same_path(output, output2)) {
       file.remove(output)
@@ -95,7 +100,8 @@ bs4_book_build <- function(output = "bookdown.html",
                            repo = NULL,
                            lib_dir = "libs",
                            output_dir = opts$get("output_dir"),
-                           split_bib = split_bib) {
+                           split_bib = FALSE,
+                           footnotes_inline = TRUE) {
   move_files_html(output, lib_dir)
 
   rmd_index <- new.env(parent = emptyenv())
@@ -118,13 +124,15 @@ bs4_book_build <- function(output = "bookdown.html",
       output2,
       repo = repo,
       rmd_index = setNames(opts$get("input_rmd"), output2),
-      toc = build_toc(output2)
+      toc = build_toc(output2),
+      footnotes_inline = footnotes_inline
     )
   } else {
     bs4_chapters_tweak(output,
       repo = repo,
       rmd_index = unlist(as.list(rmd_index)),
-      output_dir = output_dir
+      output_dir = output_dir,
+      footnotes_inline = footnotes_inline
     )
   }
 
@@ -230,7 +238,8 @@ bs4_book_dependency <- function(theme) {
 bs4_chapters_tweak <- function(output,
                                rmd_index = NULL,
                                repo = NULL,
-                               output_dir = opts$get("output_dir")) {
+                               output_dir = opts$get("output_dir"),
+                               footnotes_inline = TRUE) {
   toc <- build_toc(output)
   files <- toc[!duplicated(toc$file_name) & !is.na(toc$file_name), ]
   files$path <- file.path(output_dir, files$file_name)
@@ -239,13 +248,13 @@ bs4_chapters_tweak <- function(output,
   for (i in seq_len(nrow(files))) {
     path <- files$path[[i]]
     message("Tweaking ", path)
-    index[[i]] <- bs4_chapter_tweak(path, toc, rmd_index = rmd_index, repo = repo)
+    index[[i]] <- bs4_chapter_tweak(path, toc, rmd_index = rmd_index, repo = repo, footnotes_inline = footnotes_inline)
   }
   # tweak 404.html ---
   path_404 <- file.path(output_dir, "404.html")
   if (file.exists(path_404)) {
     message("Tweaking ", path_404)
-    bs4_chapter_tweak(path_404, toc, rmd_index = rmd_index, repo = repo)
+    bs4_chapter_tweak(path_404, toc, rmd_index = rmd_index, repo = repo, footnotes_inline = footnotes_inline)
 
   }
   index <- unlist(index, recursive = FALSE, use.names = FALSE)
@@ -257,7 +266,7 @@ bs4_chapters_tweak <- function(output,
   )
 }
 
-bs4_chapter_tweak <- function(path, toc, rmd_index = NULL, repo = NULL) {
+bs4_chapter_tweak <- function(path, toc, rmd_index = NULL, repo = NULL, footnotes_inline = TRUE) {
   text <- xfun::file_string(path)
 
   # Convert ANSI escape to \u2029 since control characters are ignored in XML2
@@ -269,7 +278,7 @@ bs4_chapter_tweak <- function(path, toc, rmd_index = NULL, repo = NULL) {
   tweak_chapter(html)
   tweak_anchors(html)
   tweak_chunks(html)
-  tweak_footnotes(html)
+  if (isTRUE(footnotes_inline)) tweak_footnotes(html)
   tweak_part_screwup(html)
   tweak_navbar(html, toc, basename(path), rmd_index = rmd_index, repo = repo)
   tweak_metadata(html, path)
@@ -311,6 +320,7 @@ tweak_part_screwup <- function(html) {
 }
 
 tweak_footnotes <- function(html) {
+
   container <- xml2::xml_find_all(html, ".//div[@class='footnotes']")
   if (length(container) != 1) {
     return()
