@@ -192,8 +192,11 @@ gitbook_toc = function(x, cur, config) {
   if (i2 - i1 < 2) return(x)
   toc = x[(i1 + 1):(i2 - 1)]
 
+  # Remove possible empty span due to anchor section
+  toc = gsub("<span></span>(?=</[ab]>)", "", toc, perl = TRUE)
+
   # numbered sections
-  r = '^<li><a href="([^#]*)(#[^"]+)"><span class="toc-section-number">([.A-Z0-9]+)</span>(.+)(</a>.*)$'
+  r = '^<li><a href="([^#]*)(#[^"]+)"[^>]*><span class="toc-section-number">([.A-Z0-9]+)</span>(.+)(</a>.*)$'
   i = grep(r, toc)
   toc[i] = gsub(
     r,
@@ -203,7 +206,7 @@ gitbook_toc = function(x, cur, config) {
   toc[i] = sub(' data-path="">', paste0(' data-path="', with_ext(cur, '.html'), '">'), toc[i])
 
   # unnumbered sections
-  r = '^<li><a href="([^#]*)(#[^"]+)">([^<]+</a>.*)$'
+  r = '^<li><a href="([^#]*)(#[^"]+)"[^>]*>((.+)</a>.*)$'
   i = grep(r, toc)
   toc[i] = gsub(
     r,
