@@ -63,7 +63,7 @@ bookdown_site = function(input, ...) {
 # render the book via _render.R or Makefile, or fallback to render_book()
 render_book_script = function(output_format = NULL, envir = globalenv(), quiet = TRUE) {
   result = 0
-  if (length(script <- existing_r('_render', TRUE))) {
+  if (length(script <- head(existing_r('_render'), 1))) {
     result = Rscript(c(if (quiet) '--quiet', script, shQuote(output_format)))
   } else if (file.exists('Makefile')) {
     result = system2('make')
